==> haskell-assert-failure-0.1.2.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assert-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assert-failure
version:              0.1.2.6
visibility:           public
id:                   assert-failure-0.1.2.6-4pw2SiHlDdoCNIlHUMwc03
key:                  assert-failure-0.1.2.6-4pw2SiHlDdoCNIlHUMwc03
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/assert-failure
synopsis:             Syntactic sugar improving '\''assert'\'' and '\''error'\''
description:
    This library contains syntactic sugar that makes it easier
    to write simple contracts with '\''assert'\'' and '\''error'\''
    and report the values that violate contracts.

category:             Control, Contract
abi:                  381dda6a174e38e6910295f5a887ef91
exposed:              True
exposed-modules:      Control.Exception.Assert.Sugar
import-dirs:          /usr/lib/ghc-9.0.2/site-local/assert-failure-0.1.2.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/assert-failure-0.1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-assert-failure
hs-libraries:         HSassert-failure-0.1.2.6-4pw2SiHlDdoCNIlHUMwc03
depends:
    base-4.15.1.0 pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-assert-failure/html/assert-failure.haddock

haddock-html:         /usr/share/doc/haskell-assert-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-assert-failure-0.1.2.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assert-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assert-failure
version:              0.1.2.6
visibility:           public
id:                   assert-failure-0.1.2.6-BVvSp9xCgqyLEAViIGfeZR
key:                  assert-failure-0.1.2.6-BVvSp9xCgqyLEAViIGfeZR
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/assert-failure
synopsis:             Syntactic sugar improving '\''assert'\'' and '\''error'\''
description:
    This library contains syntactic sugar that makes it easier
    to write simple contracts with '\''assert'\'' and '\''error'\''
    and report the values that violate contracts.

category:             Control, Contract
abi:                  74ffbf9066821856c793b94e41780ea7
exposed:              True
exposed-modules:      Control.Exception.Assert.Sugar
import-dirs:          /usr/lib/ghc-9.0.2/site-local/assert-failure-0.1.2.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/assert-failure-0.1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-assert-failure
hs-libraries:         HSassert-failure-0.1.2.6-BVvSp9xCgqyLEAViIGfeZR
depends:
    base-4.15.1.0 pretty-show-1.10-E9zv3yZn35Y9VpF8wkb8MR text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-assert-failure/html/assert-failure.haddock

haddock-html:         /usr/share/doc/haskell-assert-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
